@@ -1,7 +1,5 @@
 #' @name ICSClust-package
 #'
-#' @docType package
-#'
 #' @title \packageTitle{ICSClust}
 #'
 #' @description \packageDescription{ICSClust}
@@ -12,9 +10,10 @@
 #' \packageIndices{ICSClust}
 #'
 #' @references
-#' Alfons, A., Archimbaud, A., Nordhausen, K., & Ruiz-Gazen, A. (2022). 
+#' Alfons, A., Archimbaud, A., Nordhausen, K., & Ruiz-Gazen, A. (2024). 
 #' Tandem clustering with invariant coordinate selection. 
-#'  \emph{arXiv preprint arXiv:2212.06108}.
+#' Econometrics and Statistics.
+#'  \doi{10.1016/j.ecosta.2024.03.002}.
 #'
 #' @author
 #' \packageAuthor{ICSClust}
@@ -22,5 +21,4 @@
 #' Maintainer: \packageMaintainer{ICSClust}
 #'
 #' @keywords package
-
-NULL
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
